import styles from "./index.module.css";
import ItemCard from "./itemCard";
import { Button, Flex } from "antd";
import Setting from "@/pages/Setting";
import { useBoolean } from "ahooks";
import { useEffect, useState } from "react";
import service from "@/service";
import { PlusCircleOutlined } from "@ant-design/icons";
import eventBus from "@/customForm/eventBus";
import AdminLogin from "@/pages/Login/adminLogin";
import useUserStore from "@/store/useUserStore";

const ManagementMain = () => {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [dataSource, setDataSource] = useState<any[]>([]);
  const { adminInfo } = useUserStore();
  const init = () => {
    setDataSource([]);
    if (adminInfo) {
      service.managementService.getAllApplication().then((res) => {
        if (res.code === 200) {
          setDataSource(res.data.list);
        }
      });
    }
  };
  useEffect(() => {
    init();
    const handleEvent = () => {
      init();
    };
    eventBus.on("updateList", handleEvent);
    return () => {
      eventBus.off("updateList", handleEvent);
    };
  }, [adminInfo]);

  return (
    <div className={styles.container}>
      <Setting visible={visible} onClose={setFalse} mode={"add"} />
      <div className={styles.header}>
        <Flex>
          <Button
            type="primary"
            icon={<PlusCircleOutlined />}
            onClick={setTrue}
          >
            添加事项
          </Button>
          <AdminLogin />
        </Flex>
      </div>
      <div className={styles.titleWrapper}>
        <div className={styles.title}>行政许可与行政备案</div>
      </div>
      <div className={styles.scrollView}>
        <div className={styles.content}>
          {dataSource.length === 0 && (
            <div className={styles.empty}>暂无需要审批的项</div>
          )}
          {dataSource?.map((item) => {
            return <ItemCard data={item}></ItemCard>;
          })}
        </div>
      </div>
    </div>
  );
};

export default ManagementMain;
