import {
  ConfigProvider,
  Flex,
  Input,
  Space,
  Table,
  TableProps,
  message,
} from "antd";
import styles from "./listTable.module.css";
import classNames from "classnames";
import { useEffect, useState } from "react";
import { SearchOutlined } from "@ant-design/icons";
import listIcon from "@/assets/images/pendingReview/list.png";
import mapIcon from "@/assets/images/pendingReview/map.png";
import cardIcon from "@/assets/images/pendingReview/card.png";
import ApplicationMaterial from "@/pages/ApplicationMaterial";
import { useBoolean } from "ahooks";

import service from "@/service";
import eventBus from "@/customForm/eventBus";

const TagTab = ({ activeTab, tags, onChange }: any) => {
  return (
    <Flex gap={14} align="center">
      {tags.map((item: any, index: number) => {
        return (
          <div
            onClick={onChange.bind(this, index)}
            className={classNames(
              styles.tagItem,
              index === activeTab ? styles.active : ""
            )}
          >
            {item.elementName}&nbsp;{item.elementCount}
          </div>
        );
      })}
    </Flex>
  );
};

const ListTable = (props: { applicationInfo: any; active?: string }) => {
  const { applicationInfo, active } = props;
  const [showDetail, { setFalse, setTrue }] = useBoolean(false);
  const [actionObj, setActionObj] = useState<any>();
  const [activeTab, setActiveTab] = useState(0);

  const [inputStr, setInputStr] = useState("");

  const flowList = applicationInfo?.nodeCount;
  const [paginationInfo, setPaginationInfo] = useState<any>();
  const [dataSource, setDataSource] = useState<any[]>([]);
  useEffect(() => {
    if (active && active.length > 0) {
      const index = flowList.findIndex(
        (item: any) => item.elementId === active
      );
      setActiveTab(index);
    } else {
      setActiveTab(0);
    }
  }, [active]);

  useEffect(() => {
    getData(1);
  }, [activeTab, inputStr, applicationInfo]);

  useEffect(() => {
    const handler = () => {
      setFalse();
    };
    eventBus.on("updateTableList", handler);
    return () => eventBus.off("updateTableList", handler);
  }, []);

  const getData = (pageNum: number) => {
    const params = {
      thingId: applicationInfo.id,
      name: inputStr,
      elementId: flowList[activeTab]?.elementId ?? undefined,
      pageNum: pageNum,
      pageSize: 6,
    };
    service.managementService.getApplicationRecordById(params).then((res) => {
      if (res.code === 200) {
        setDataSource(res.data?.list);
        setPaginationInfo(res.data);
      }
    });
  };
  const columns: TableProps<any>["columns"] = [
    {
      title: "申请编号",
      dataIndex: "id",
    },
    {
      title: "申请单位",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "申请时间",
      dataIndex: "createAt",
      key: "createAt",
    },
    {
      title: "办理阶段",
      key: "nodeNameAlias",
      dataIndex: "nodeNameAlias",
    },
    {
      title: "办理说明",
      dataIndex: "applicantType",
      key: "applicantType",
    },
    {
      title: "操作",
      key: "action",
      render: (_, record) => (
        <Space
          size="middle"
          onClick={() => {
            setActionObj(record);
            setTrue();
          }}
        >
          <a>办理</a>
        </Space>
      ),
    },
  ];

  const clickHandle = (index: number) => {
    setActiveTab(index);
  };

  const inputChange = (e: any) => {
    const value = e.target.value;
    setInputStr(value);
  };

  return (
    <>
      <ApplicationMaterial
        visible={showDetail}
        mode="review"
        actionObj={actionObj}
        onClose={setFalse}
      ></ApplicationMaterial>
      <div className={styles.container}>
        <Flex style={{ margin: "24px 0" }} justify="space-between">
          <TagTab
            activeTab={activeTab}
            tags={flowList}
            onChange={clickHandle}
          ></TagTab>
          <Space>
            <Input
              placeholder="输入申请单位名称搜索"
              prefix={<SearchOutlined />}
              style={{ height: 50 }}
              onChange={inputChange}
            ></Input>
            <div className={styles.iconBtn}>
              <img
                src={listIcon}
                alt=""
                style={{ width: 18, height: 18 }}
              ></img>
            </div>
            <div
              className={styles.iconBtn}
              onClick={() => {
                message.info("功能待开发");
              }}
            >
              <img
                src={cardIcon}
                alt=""
                style={{ width: 18, height: 18 }}
              ></img>
            </div>
            <div
              className={styles.iconBtn}
              onClick={() => {
                message.info("功能待开发");
              }}
            >
              <img src={mapIcon} alt="" style={{ width: 18, height: 18 }}></img>
            </div>
          </Space>
        </Flex>
        <ConfigProvider
          theme={{
            components: {
              Table: {
                headerColor: "rgba(139, 146, 159, 1)",
                headerBg: "#fff",
                rowHoverBg: "#EDF5FF",
                borderColor: "transparent",
              },
            },
          }}
        >
          <Table
            columns={columns}
            dataSource={dataSource}
            pagination={{
              pageSize: 6,
              total: paginationInfo?.total,
              current: paginationInfo?.pageNum,
              onChange: (pageNum) => {
                getData(pageNum);
              },
            }}
          />
        </ConfigProvider>
      </div>
    </>
  );
};

export default ListTable;
